@@ -7,8 +7,7 @@ check() {
 }
 
 depends() {
-    echo initqueue
-    return 0
+    echo base fs-lib
 }
 
 installkernel() {
@@ -21,7 +20,6 @@ install() {
         mkdir mount readlink rmdir sed stat umount \
         fll_blockdev_detect
     inst_simple /etc/default/distro
-    inst_hook pre-udev 30 "$moddir/fll.sh"
-    inst_script "$moddir/fll-udev.sh" "/sbin/fll-udev"
-    inst_script "/usr/share/fll-live-initramfs/fll.initramfs" "/sbin/fll-live-root"
+    inst_hook mount 99 "$moddir/fll.sh"
+    inst_script "/usr/share/fll-live-initramfs/fll.initramfs" "/sbin/fll"
 }
